==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTFUNCTIONLEVELID.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTFUNCTIONLEVELCODE"/>
 *         <element name="DESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentfunctionlevelcode",
    "description"
})
@XmlRootElement(name = "EQUIPMENTFUNCTIONLEVELID")
public class EQUIPMENTFUNCTIONLEVELID {

    @XmlElement(name = "EQUIPMENTFUNCTIONLEVELCODE", required = true)
    protected String equipmentfunctionlevelcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the equipmentfunctionlevelcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTFUNCTIONLEVELCODE() {
        return equipmentfunctionlevelcode;
    }

    /**
     * Sets the value of the equipmentfunctionlevelcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTFUNCTIONLEVELCODE(String value) {
        this.equipmentfunctionlevelcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTFUNCTIONLEVELID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTFUNCTIONLEVELCODE"/>
 *         &lt;element name="DESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentfunctionlevelcode",
    "description"
})
@XmlRootElement(name = "EQUIPMENTFUNCTIONLEVELID")
public class EQUIPMENTFUNCTIONLEVELID {

    @XmlElement(name = "EQUIPMENTFUNCTIONLEVELCODE", required = true)
    protected String equipmentfunctionlevelcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the equipmentfunctionlevelcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTFUNCTIONLEVELCODE() {
        return equipmentfunctionlevelcode;
    }

    /**
     * Sets the value of the equipmentfunctionlevelcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTFUNCTIONLEVELCODE(String value) {
        this.equipmentfunctionlevelcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
